pub struct AnyExpression { /* private fields */ }Expand description
Type-erased expression that can be downcast to concrete expression types
Implementations
Sourceimpl AnyExpression
impl AnyExpression
Sourcepub fn new<T>(expr: T) -> AnyExpression
pub fn new<T>(expr: T) -> AnyExpression
Create a new AnyExpression from a concrete expression type
Sourcepub fn downcast<T>(self) -> Result<T, AnyExpression>where
T: Clone + 'static,
pub fn downcast<T>(self) -> Result<T, AnyExpression>where
T: Clone + 'static,
Attempt to downcast to a concrete expression type
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: 'static,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: 'static,
Get a reference to the expression as a specific type